# Generated by Django 4.1.5 on 2023-01-31 12:08

import allauth_sms.models
from django.db import migrations, models
import phonenumber_field.modelfields


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="OTP",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "phone",
                    phonenumber_field.modelfields.PhoneNumberField(
                        max_length=128, region=None
                    ),
                ),
                ("ctime", models.DateTimeField(auto_now_add=True)),
                (
                    "code",
                    models.CharField(
                        default=allauth_sms.models.generate_code, max_length=6
                    ),
                ),
                ("is_used", models.BooleanField(default=False)),
            ],
        ),
    ]
